@@ -3,6 +3,9 @@ use Modern::Perl;
 use Moo;
 use Types::Standard qw(Str);
 use IPC::Cmd qw(run can_run);
+use Alien::UnRTF;
+use Env qw( @PATH );
+unshift @PATH, Alien::UnRTF->bin_dir;  # unrtf is now in $PATH
 
 =head1 NAME
 
@@ -23,7 +26,7 @@ See: L<http://www.gnu.org/software/unrtf>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2013 Joenio Costa
+Copyright (C) 2013-2021 Joenio Marques da Costa
 
 =cut
 
